function [psol,tangent]=dde_psol_from_hopf(point,varargin)
%% Create small amplitude harmonic oscillation around Hopf point
%
% Output is initial periodic orbit and approximate tangent
% (c) DDE-BIFTOOL v. 3.2a(308), 28/10/2018
%%
default={'radius',1e-3,'degree',3,'intervals',20};
[options,pass_on]=dde_set_options(default,varargin,'pass_on');
if ~strcmp(point.kind,'hopf')
    point=dde_apply({'dde_hopf_from_',point.kind,''},point,pass_on{:});
end
if point.omega==0
    warning('dde_psol_from_hopf:zerofrequency',...
        'zero frequency in Hopf point, period set to Inf');
end
ntst=options.degree*options.intervals+1;
psol=dde_psol_create('point',point,...
    'mesh',linspace(0,1,ntst),...
    'degree',options.degree,...
    'period',2*pi/abs(point.omega),...
    'profile',repmat(point.x,1,ntst));
%% harmonic profile
harmonic=imag(point.v*exp(1i*2*pi*psol.mesh));
%% initial solution has small amplitude harmonic aroun equilibrium
psol.profile=psol.profile+options.radius*harmonic;
tangent=dde_psol_create('point',psol,...
    'period',0,...
    'profile',harmonic,...
    'parameter',0*psol.parameter);
end
